import cx from 'clsx';
import { FC, useCallback, useEffect, useState } from 'react';
import styles from './Switch.module.css';

type SwitchProps = {
  name?: string;
  checked?: boolean;
  disabled?: boolean;
  onChange?: (checked: boolean) => void;
};

const Switch: FC<SwitchProps> = ({ name, checked = false, disabled = false, onChange }) => {
  const [isChecked, setChecked] = useState(checked);
  const handleChange = useCallback(() => {
    if (!disabled) {
      setChecked((prev) => !prev);
      onChange?.(!isChecked);
    }
  }, [disabled, onChange, isChecked]);

  useEffect(() => {
    if (checked !== isChecked) {
      setChecked(checked);
    }
  }, [checked]);

  return (
    <div aria-disabled={disabled} className={styles.switch}>
      <div
        className={cx(styles.switch_handle, isChecked && styles.checked)}
        onClick={handleChange}
      />
      {name !== undefined && (
        <input type="hidden" name={name} value={isChecked ? 'true' : 'false'} />
      )}
    </div>
  );
};

export default Switch;
