import cx from 'clsx';
import { useAtom } from 'jotai';
import { FC, useCallback } from 'react';
import { Pulse } from '../../context/pattern-model';
import { SelectedPulseIdAtom } from '../../context/Patterns';
import styles from './PulseCard.module.css';

type PulseCardProps = {
  pulse: Pulse;
};

const PulseCard: FC<PulseCardProps> = ({ pulse }) => {
  const [selected, setSelected] = useAtom(SelectedPulseIdAtom);

  const handleSelect = useCallback(() => {
    if (selected === pulse.id) {
      setSelected(null);
    } else {
      setSelected(pulse.id);
    }
  }, [pulse, selected]);

  return (
    <div
      className={cx(styles.pulse_card, selected === pulse.id && styles.selected)}
      onClick={handleSelect}>
      <div className={styles.order}>{pulse.order.toString().padStart(3, '0')}</div>
      <div className="spacer" />
      <div className={styles.offset}>+ {pulse.offset} ms</div>
    </div>
  );
};

export default PulseCard;
