import cx from 'clsx';
import { useSetAtom } from 'jotai';
import { FC, useActionState } from 'react';
import { useNavigate } from 'react-router-dom';
import { NotificationType, ToastDuration, useNotification } from '../components/Notifications';
import { SelectedPatternIdAtom, useSavePattern } from '../context/Patterns';
import styles from './CreatePattern.module.css';

const CreatePattern: FC = () => {
  const { showToast } = useNotification();
  const navigate = useNavigate();
  const loadPattern = useSetAtom(SelectedPatternIdAtom);
  const savePattern = useSavePattern();

  const [errState, handleFormSubmit] = useActionState(async (state, formData) => {
    const patternName = formData.get('pattern_name') as string | null;

    if (patternName === null || patternName.length === 0) {
      showToast(
        NotificationType.ERROR,
        'Please enter a pattern name.',
        'material-symbols-light:error-outline',
        ToastDuration.MEDIUM,
      );
      return true;
    }

    const newPattern = new Pattern();
    newPattern.name = patternName;

    try {
      const updated = await savePattern(newPattern);
      if (!updated) {
        showToast(
          NotificationType.ERROR,
          'Failed to reload the created pattern. Please try again.',
          'material-symbols-light:error-outline',
          ToastDuration.MEDIUM,
        );
        loadPattern(null);
        navigate('/library');
        return true;
      }
      loadPattern(newPattern.id);
      navigate('/pattern-editor/edit');
    } catch (e) {
      console.error('[save pattern]', e);
      loadPattern(null);
      showToast(
        NotificationType.ERROR,
        'Failed to create pattern. Please try again.',
        'material-symbols-light:error-outline',
        ToastDuration.MEDIUM,
      );
    }

    return false;
  }, false);

  return (
    <div className={cx('workspace', 'vertical', styles.create_form)}>
      <div className="center">
        <form action={handleFormSubmit} className={styles.form_row}>
          <input
            type="text"
            name="pattern_name"
            placeholder="pattern name"
            className={cx(styles.pattern_name_input, errState && 'error')}
          />
          <button type="submit" className="filled">
            Create New Pattern
          </button>
        </form>
      </div>
    </div>
  );
};

export default CreatePattern;
